package com.ruoyi.postCheck.controller;

import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.postCheck.domain.PostTeamDept;
import com.ruoyi.postCheck.service.IPostTeamDeptService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiImplicitParam;

/**
 * 岗检工作组关联部门Controller
 *
 * @author csg
 * @date 2023-12-19
 */
@Api(tags = "2.2.2-岗检工作组添加岗检小组接口（废弃-2023年12月21日）")
@RestController
@RequestMapping("/postCheck/teamDept")
public class PostTeamDeptController extends BaseController
{
    @Autowired
    private IPostTeamDeptService postTeamDeptService;

    /**
     * 查询岗检工作组关联部门列表
     */
    @ApiOperation("查询岗检工作组关联部门列表")
    @PreAuthorize("@ss.hasPermi('postCheck:teamDept:list')")
    @GetMapping("/list")
    public TableDataInfo list(PostTeamDept postTeamDept)
    {
        startPage();
        List<PostTeamDept> list = postTeamDeptService.selectPostTeamDeptList(postTeamDept);
        return getDataTable(list);
    }

    /**
     * 导出岗检工作组关联部门列表
     */
    @ApiOperation("导出岗检工作组关联部门列表")
    @PreAuthorize("@ss.hasPermi('postCheck:teamDept:export')")
    @Log(title = "岗检工作组关联部门", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PostTeamDept postTeamDept)
    {
        List<PostTeamDept> list = postTeamDeptService.selectPostTeamDeptList(postTeamDept);
        ExcelUtil<PostTeamDept> util = new ExcelUtil<PostTeamDept>(PostTeamDept.class);
        util.exportExcel(response, list, "岗检工作组关联部门数据");
    }

    /**
     * 获取岗检工作组关联部门详细信息
     */
    @ApiOperation("获取岗检工作组关联部门详细信息")
    @PreAuthorize("@ss.hasPermi('postCheck:teamDept:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(postTeamDeptService.selectPostTeamDeptById(id));
    }

    /**
     * 新增岗检工作组关联部门
     */
    @ApiOperation("新增岗检工作组关联部门")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "id", value = "主键", dataType = "Long", dataTypeClass = Long.class),
        @ApiImplicitParam(name = "postTeamId", value = "岗检工作组ID", dataType = "String", dataTypeClass = String.class),
        @ApiImplicitParam(name = "groupTeamName", value = "岗检工作组名称（与部门不相关，自定义的名称，例如：综合岗检工作组、生产岗检工作组）", dataType = "String", dataTypeClass = String.class),
        @ApiImplicitParam(name = "type", value = "类型（1-牵头部门；2-成员部门）", dataType = "Long", dataTypeClass = Long.class),
        @ApiImplicitParam(name = "delFlag", value = "del_flag", dataType = "Integer", dataTypeClass = Integer.class),
        @ApiImplicitParam(name = "createUserId", value = "创建者用户ID", dataType = "Long", dataTypeClass = Long.class),
    })
    @PreAuthorize("@ss.hasPermi('postCheck:teamDept:add')")
    @Log(title = "岗检工作组关联部门", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PostTeamDept postTeamDept)
    {
        return toAjax(postTeamDeptService.insertPostTeamDept(postTeamDept));
    }

    /**
     * 修改岗检工作组关联部门
     */
    @ApiOperation("修改岗检工作组关联部门")
    @PreAuthorize("@ss.hasPermi('postCheck:teamDept:edit')")
    @Log(title = "岗检工作组关联部门", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PostTeamDept postTeamDept)
    {
        return toAjax(postTeamDeptService.updatePostTeamDept(postTeamDept));
    }

    /**
     * 删除岗检工作组关联部门
     */
    @ApiOperation("删除岗检工作组关联部门")
    @PreAuthorize("@ss.hasPermi('postCheck:teamDept:remove')")
    @Log(title = "岗检工作组关联部门", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(postTeamDeptService.deletePostTeamDeptByIds(ids));
    }
}
